@@ -1,6 +1,6 @@
 package JIRA::REST;
 {
-  $JIRA::REST::VERSION = '0.006';
+  $JIRA::REST::VERSION = '0.007';
 }
 # ABSTRACT: Thin wrapper around JIRA's REST API
 
@@ -92,9 +92,23 @@ sub _error {
         $msg .= $content;
     } elsif ($type =~ m:application/json:) {
         my $error = $self->{json}->decode($content);
-        if (ref $error eq 'HASH' && exists $error->{errorMessages}) {
-            foreach my $message (@{$error->{errorMessages}}) {
-                $msg .= "- $message\n";
+        if (ref $error eq 'HASH') {
+            # JIRA errors may be laid out in all sorts of ways. You have to
+            # look them up from the scant documentation at
+            # https://docs.atlassian.com/jira/REST/latest/.
+
+            # /issue/bulk tucks the errors one level down, inside the
+            # 'elementErrors' hash.
+            $error = $error->{elementErrors} if exists $error->{elementErrors};
+
+            # Some methods tuck the errors in the 'errorMessages' array.
+            if (my $errorMessages = $error->{errorMessages}) {
+                $msg .= "- $_\n" foreach @$errorMessages;
+            }
+
+            # And some tuck them in the 'errors' hash.
+            if (my $errors = $error->{errors}) {
+                $msg .= "- [$_] $errors->{$_}\n" foreach sort keys %$errors;
             }
         } else {
             $msg .= $content;
@@ -240,7 +254,7 @@ JIRA::REST - Thin wrapper around JIRA's REST API
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
